#
# spec file for package python-asdf-transform-schemas
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-asdf-transform-schemas%{psuffix}
Version:        0.5.0
Release:        1.2
Summary:        ASDF schemas for transforms
License:        BSD-3-Clause
URL:            https://github.com/asdf-format/asdf-transform-schemas
Source:         https://files.pythonhosted.org/packages/source/a/asdf-transform-schemas/asdf_transform_schemas-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 42}
BuildRequires:  %{python_module setuptools_scm >= 3.4}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-asdf-standard >= 1.1
%if %{with test}
BuildRequires:  %{python_module asdf-astropy}
BuildRequires:  %{python_module asdf-transform-schemas = %{version}}
BuildRequires:  %{python_module asdf}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
%endif
Provides:       python-asdf_transform_schemas = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
ASDF schemas for transforms

%prep
%setup -q -n asdf_transform_schemas-%{version}
sed -i "/addopts = '--color=yes'/d" pyproject.toml

%if !%{with test}
%build
%pyproject_wheel
%endif

%if !%{with test}
%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# gh#asdf-format/asdf-transform-schemas#114
donttest="(label_mapper-1.3.0.yaml and test_example_2)"
%pytest -v -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/asdf_transform_schemas
%{python_sitelib}/asdf_transform_schemas-%{version}.dist-info
%endif

%changelog
* Sun Mar 10 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.0
  * Update schemas for ASDF standard 1.6.0 [#110]
* Sun Feb 18 2024 Ben Greiner <code@bnavigator.de>
- Tests require asdf-astropy and scipy which got lost as transitive
  dependencies -- gh#asdf-format/asdf-transform-schemas#106
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.0:
  * Move root-level $ref in schemas to an allOf combiner. [#87]
  * Fix URI fragment format in transform-1.2 schema. [#88]
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.3.0
  * Add schemas to properly support bounding_box and
    compound_bounding_box.
  * Add fixed and bounds to base transform schema to properly
    document them.
  * Add input_units_equivalencies to base transform schema to
    properly document it.
  * Update spline1d schema.
  * Add Schechter1D schema.
  * Fix fix_inputs tag bug.
  * Create docs for package.
  * Move packaging configuration to pyproject.toml.
  * Remove unnecessary tag: entry from all schemas.
* Sun Mar 13 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.2.2
  * Add inputs and outputs to base transform schema to properly
    document them. [#33]
  * Add spline1d schema. [#41]
  * Add cosine, tangent, arcsine, arccosine, and arctangent
    schemas. [#40]
  * Fix circular build dependencies for asdf. [#38]
- Make _multibuild in order to avoid build cycles
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.2.0
- Required by python-asdf-astropy which is required by gwcs-0.18
